#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-hspec
version:              1.2
visibility:           public
id:                   tasty-hspec-1.2-1tyezRxDc4Fipcmn7B2qn
key:                  tasty-hspec-1.2-1tyezRxDc4Fipcmn7B2qn
license:              BSD-3-Clause
maintainer:           mitchellwrosen@gmail.com
author:               Mitchell Rosen
homepage:             https://github.com/mitchellwrosen/tasty-hspec
synopsis:             Hspec support for the Tasty test framework.
description:
    This package provides a Tasty provider for Hspec test
    suites.

category:             Testing
abi:                  269849b18aca49bca56102e611e6cbf1
exposed:              True
exposed-modules:      Test.Tasty.Hspec
hidden-modules:       Test.Tasty.Hspec.Compat
import-dirs:          /usr/lib/ghc-8.10.5/site-local/tasty-hspec-1.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/tasty-hspec-1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/tasty-hspec-1.2
hs-libraries:         HStasty-hspec-1.2-1tyezRxDc4Fipcmn7B2qn
depends:
    QuickCheck-2.14.2-LYkEXWaccd95SoKseYSYTk base-4.14.2.0
    hspec-2.8.2-HK9g9sLkinxIQHVOkGJsHm
    hspec-core-2.8.2-KreUZRtyr6gCcePVHn4DmC
    tasty-1.4.1-o6GqK7uhQW6VZVrPJnWQG
    tasty-quickcheck-0.10.1.2-Dx1vk87SXVxKJjmuKMUSyW
    tasty-smallcheck-0.8.2-Geur11evTPN7LTyUmypL8N

haddock-interfaces:   /usr/share/doc/haskell-tasty-hspec/html/tasty-hspec.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hspec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

